==> wallaroo-2023.2.0rc1-py3-none-any.whl: wallaroo/wallaroo_ml_ops_api_client/api/model/models_upload.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.models_upload_multipart_data import ModelsUploadMultipartData
from ...models.models_upload_response_200 import ModelsUploadResponse200
from ...models.models_upload_response_400 import ModelsUploadResponse400
from ...models.models_upload_response_401 import ModelsUploadResponse401
from ...models.models_upload_response_500 import ModelsUploadResponse500
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    multipart_data: ModelsUploadMultipartData,

) -> Dict[str, Any]:
    url = "{}/v1/api/models/upload".format(
        client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    

    

    

    

    multipart_multipart_data = multipart_data.to_multipart()




    return {
	    "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "files": multipart_multipart_data,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[ModelsUploadResponse200, ModelsUploadResponse400, ModelsUploadResponse401, ModelsUploadResponse500]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ModelsUploadResponse200.from_dict(response.json())



        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = ModelsUploadResponse400.from_dict(response.json())



        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = ModelsUploadResponse401.from_dict(response.json())



        return response_401
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:
        response_500 = ModelsUploadResponse500.from_dict(response.json())



        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[Union[ModelsUploadResponse200, ModelsUploadResponse400, ModelsUploadResponse401, ModelsUploadResponse500]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    multipart_data: ModelsUploadMultipartData,

) -> Response[Union[ModelsUploadResponse200, ModelsUploadResponse400, ModelsUploadResponse401, ModelsUploadResponse500]]:
    """ Uploads a model to storage

     Uploads a model to storage.

    Args:
        multipart_data (ModelsUploadMultipartData):  Model upload request.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ModelsUploadResponse200, ModelsUploadResponse400, ModelsUploadResponse401, ModelsUploadResponse500]]
     """


    kwargs = _get_kwargs(
        client=client,
multipart_data=multipart_data,

    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    *,
    client: Client,
    multipart_data: ModelsUploadMultipartData,

) -> Optional[Union[ModelsUploadResponse200, ModelsUploadResponse400, ModelsUploadResponse401, ModelsUploadResponse500]]:
    """ Uploads a model to storage

     Uploads a model to storage.

    Args:
        multipart_data (ModelsUploadMultipartData):  Model upload request.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ModelsUploadResponse200, ModelsUploadResponse400, ModelsUploadResponse401, ModelsUploadResponse500]
     """


    return sync_detailed(
        client=client,
multipart_data=multipart_data,

    ).parsed

async def asyncio_detailed(
    *,
    client: Client,
    multipart_data: ModelsUploadMultipartData,

) -> Response[Union[ModelsUploadResponse200, ModelsUploadResponse400, ModelsUploadResponse401, ModelsUploadResponse500]]:
    """ Uploads a model to storage

     Uploads a model to storage.

    Args:
        multipart_data (ModelsUploadMultipartData):  Model upload request.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ModelsUploadResponse200, ModelsUploadResponse400, ModelsUploadResponse401, ModelsUploadResponse500]]
     """


    kwargs = _get_kwargs(
        client=client,
multipart_data=multipart_data,

    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(
            **kwargs
        )

    return _build_response(client=client, response=response)

async def asyncio(
    *,
    client: Client,
    multipart_data: ModelsUploadMultipartData,

) -> Optional[Union[ModelsUploadResponse200, ModelsUploadResponse400, ModelsUploadResponse401, ModelsUploadResponse500]]:
    """ Uploads a model to storage

     Uploads a model to storage.

    Args:
        multipart_data (ModelsUploadMultipartData):  Model upload request.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ModelsUploadResponse200, ModelsUploadResponse400, ModelsUploadResponse401, ModelsUploadResponse500]
     """


    return (await asyncio_detailed(
        client=client,
multipart_data=multipart_data,

    )).parsed

==> wallaroo-2023.4.0b2-py3-none-any.whl: wallaroo/wallaroo_ml_ops_api_client/api/model/models_upload.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ... import errors
from ...client import Client
from ...models.upload_payload_doc import UploadPayloadDoc
from ...models.upload_response import UploadResponse
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    multipart_data: UploadPayloadDoc,

) -> Dict[str, Any]:
    url = "{}/v1/api/models/upload".format(
        client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    

    

    

    

    multipart_multipart_data = multipart_data.to_multipart()




    return {
	    "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "files": multipart_multipart_data,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[UploadResponse]:
    if response.status_code == HTTPStatus.OK:
        response_200 = UploadResponse.from_dict(response.json())



        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[UploadResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    multipart_data: UploadPayloadDoc,

) -> Response[UploadResponse]:
    """ 
    Args:
        multipart_data (UploadPayloadDoc):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[UploadResponse]
     """


    kwargs = _get_kwargs(
        client=client,
multipart_data=multipart_data,

    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    *,
    client: Client,
    multipart_data: UploadPayloadDoc,

) -> Optional[UploadResponse]:
    """ 
    Args:
        multipart_data (UploadPayloadDoc):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        UploadResponse
     """


    return sync_detailed(
        client=client,
multipart_data=multipart_data,

    ).parsed

async def asyncio_detailed(
    *,
    client: Client,
    multipart_data: UploadPayloadDoc,

) -> Response[UploadResponse]:
    """ 
    Args:
        multipart_data (UploadPayloadDoc):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[UploadResponse]
     """


    kwargs = _get_kwargs(
        client=client,
multipart_data=multipart_data,

    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(
            **kwargs
        )

    return _build_response(client=client, response=response)

async def asyncio(
    *,
    client: Client,
    multipart_data: UploadPayloadDoc,

) -> Optional[UploadResponse]:
    """ 
    Args:
        multipart_data (UploadPayloadDoc):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        UploadResponse
     """


    return (await asyncio_detailed(
        client=client,
multipart_data=multipart_data,

    )).parsed
